pyia
====

A Python package for working with *Gaia* data.

|Coverage Status| |Build status|

Documentation
-------------

|Documentation Status|

The documentation for ``pyia`` is hosted on `Read the Docs
<http://pyia.rtfd.io>`_.

Installation and Dependencies
-----------------------------

See the `installation
instructions <http://pyia.rtfd.io/en/latest/install.html>`_ in the
`documentation <http://pyia.rtfd.io>`_ for more information.

License
-------

|License|

Copyright 2017-2018 Adrian Price-Whelan and contributors.

``Pyia`` is free software made available under the MIT License. For details see
the `LICENSE <https://github.com/adrn/pyia/blob/master/LICENSE>`_ file.

.. |Coverage Status| image:: https://coveralls.io/repos/adrn/pyia/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/adrn/pyia?branch=master
.. |Build status| image:: http://img.shields.io/travis/adrn/pyia/master.svg?style=flat
   :target: http://travis-ci.org/adrn/pyia
.. |License| image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/adrn/pyia/blob/master/LICENSE
.. |Documentation Status| image:: https://readthedocs.org/projects/pyia/badge/?version=latest
   :target: http://pyia.readthedocs.io/en/latest/?badge=latest
.. |Affiliated package| image:: https://img.shields.io/badge/astropy-affiliated%20package-orange.svg
   :target: http://astropy.org/affiliated
